@@ -1,18 +1,21 @@
 import pygame
-from pyengine.Exceptions import CompatibilityError
+
 from pyengine.Components.PositionComponent import PositionComponent
-from pyengine.Utils import Vec2
+from pyengine.Exceptions import CompatibilityError
+from pyengine.Utils.Vec2 import Vec2
 
 __all__ = ["SpriteComponent"]
 
 
 class SpriteComponent:
-    def __init__(self, image: str, scale: int = 1, rotation: int = 0):
+    def __init__(self, image: str, scale: int = 1, rotation: int = 0, flipx: bool = False, flipy: bool = False):
         self.__entity = None
         self.__sprite = image
         self.__scale = scale
-        self.firstrotation = rotation
-        self.__rotation = 0
+        self.__rotation = rotation
+        self.__flipx = flipx
+        self.__flipy = flipy
+        self.origin_image = None
         self.width = 0
         self.height = 0
 
@@ -33,7 +36,10 @@ class SpriteComponent:
         self.width = self.entity.rect.width
         self.height = self.entity.rect.height
         self.scale = self.scale
-        self.rotation = self.firstrotation
+        self.origin_image = self.__entity.image
+        self.rotation = self.rotation
+        self.flipx = self.flipx
+        self.flipy = self.flipy
 
     @property
     def scale(self):
@@ -42,21 +48,28 @@ class SpriteComponent:
     @scale.setter
     def scale(self, scale):
         self.__scale = scale
+        center = self.entity.rect.center
         self.entity.image = pygame.transform.scale(self.entity.image, (round(self.width * scale),
                                                                        round(self.height * scale)))
-        self.update_entity()
+        self.origin_image = self.__entity.image
+        self.entity.rect = self.entity.image.get_rect(center=center)
+        self.update_position()
 
     @property
     def size(self):
-        return [self.width, self.height]
+        return Vec2(self.width, self.height)
 
     @size.setter
     def size(self, size):
-        if not isinstance(size, Vec2):
+        if not isinstance(size, pygame.Vector2):
             raise TypeError("Size must be a Vec2")
+        center = self.entity.rect.center
         self.width, self.height = size.coords
         self.entity.image = pygame.transform.scale(self.entity.image, size.coords)
+        self.origin_image = self.__entity.image
         self.scale = 1
+        self.entity.rect = self.entity.image.get_rect(center=center)
+        self.update_position()
 
     @property
     def rotation(self):
@@ -64,10 +77,18 @@ class SpriteComponent:
 
     @rotation.setter
     def rotation(self, rotation):
-        temp = self.__rotation
+        from pyengine.Components.PhysicsComponent import PhysicsComponent
+        if self.entity.has_component(PhysicsComponent):
+            self.entity.get_component(PhysicsComponent).update_rot(rotation)
+        else:
+            self.make_rotation(rotation)
+
+    def make_rotation(self, rotation):
+        center = self.entity.rect.center
+        self.entity.image = pygame.transform.rotate(self.origin_image, rotation)
         self.__rotation = rotation
-        self.entity.image = pygame.transform.rotate(self.entity.image, self.__rotation - temp)
-        self.update_entity()
+        self.entity.rect = self.entity.image.get_rect(center=center)
+        self.update_position()
 
     @property
     def sprite(self):
@@ -81,14 +102,28 @@ class SpriteComponent:
         self.height = self.entity.rect.height
         self.entity.image = pygame.transform.scale(self.entity.image, (round(self.width * self.scale),
                                                                        round(self.height * self.scale)))
+        self.origin_image = self.entity.image
         self.update_position()
 
+    @property
+    def flipx(self):
+        return self.__flipx
+
+    @flipx.setter
+    def flipx(self, val):
+        self.entity.image = pygame.transform.flip(self.origin_image, val, 0)
+        self.__flipx = val
+
+    @property
+    def flipy(self):
+        return self.__flipy
+
+    @flipy.setter
+    def flipy(self, val):
+        self.entity.image = pygame.transform.flip(self.origin_image, 0, val)
+        self.__flipy = val
+
     def update_position(self):
         if self.entity.has_component(PositionComponent):
             position = self.entity.get_component(PositionComponent)
-            self.entity.rect.x = position.position.x + position.offset.x
-            self.entity.rect.y = position.position.y + position.offset.y
-
-    def update_entity(self):
-        self.entity.rect = self.entity.image.get_rect()
-        self.update_position()
+            self.entity.rect = self.entity.image.get_rect(center=position.position + position.offset)
